#!/bin/sh
#
# Script to back uninstall Seattle Firewall
#
#     This program is under GPL [http://www.gnu.org/copyleft/gpl.htm]         
#
#     (c) 2000 - Tom Eastep (teastep@evergo.net)
#
#       Seawall documentation is available at http://seawall.sourceforge.net
#
#       This program is free software; you can redistribute it and/or modify
#       it under the terms of Version 2 of the GNU General Public License 
#       as published by the Free Software Foundation.
#
#       This program is distributed in the hope that it will be useful,
#       but WITHOUT ANY WARRANTY; without even the implied warranty of
#       MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
#       GNU General Public License for more details.
#
#       You should have received a copy of the GNU General Public License
#       along with this program; if not, write to the Free Software
#       Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA
#
#    Usage:
#
#       You may only use this script to uninstall the version
#       shown below. Simply run this script to remove Seattle Firewall

VERSION=3.1

usage() # $1 = exit status
{
    ME=`basename $0`
    echo "usage: $ME"
    exit $1
}

restore_file() # $1 = file to restore
{
    if [ -f ${1}-seawall.bkout ]; then
	if (mv -f ${1}-seawall.bkout $1); then
	    echo
	    echo "$1 restored"
        else
	    exit 1
        fi
    fi	
}

remove_file() # $1 = file to restore
{
    if [ -f $1 -o -L $1 ] ; then
	rm -f $1
	echo "$1 Removed"
    fi
}

if [ -f /etc/seawall/version ]; then
    INSTALLED_VERSION="`cat /etc/seawall/version`"
    if [ "$INSTALLED_VERSION" != "$VERSION" ]; then
	echo "WARNING: Seattle Firewall Version $INSTALLED_VERSION is installed"
	echo "         and this is the $VERSION uninstaller."
	VERSION="$INSTALLED_VERSION"
    fi
else
    echo "WARNING: Seattle Firewall Version $VERSION is not installed"
    VERSION=""
fi

echo "Uninstalling Seattle Firewall $VERSION"

if [ -L /etc/seawall/firewall ]; then
    FIREWALL=`ls -l /etc/seawall/firewall | sed 's/^.*> //'`

    if [ -x /sbin/chkconfig -o -x /usr/sbin/chkconfig ]; then
	chkconfig --del `basename $FIREWALL`
    fi

    remove_file $FIREWALL
fi

remove_file /sbin/seawall

remove_file /etc/seawall.conf

if [ -n "$VERSION" ]; then
    remove_file /etc/seawall.conf.$VERSION
    restore_file /etc/rc.d/rc.local
    remove_file /etc/seawall/apps-${VERSION}.bkout
    remove_file /etc/seawall/servers-${VERSION}.bkout
    remove_file /etc/seawall/tunnels-${VERSION}.bkout
    remove_file /etc/seawall/version-${VERSION}.bkout
fi

remove_file /etc/seawall/firewall

remove_file /etc/seawall/apps

remove_file /etc/seawall/servers

remove_file /etc/seawall/tunnels

remove_file /etc/seawall/version

rmdir /etc/seawall

echo "Seattle Seawall Uninstalled"


